# Agnostic Robot Middleware

 [![pipeline status](https://git.whoi.edu/ros/armw/badges/master/pipeline.svg)](https://git.whoi.edu/ros/armw/-/commits/master) 
 [![coverage report](https://git.whoi.edu/ros/armw/badges/master/coverage.svg)](https://git.whoi.edu/ros/armw/-/commits/master) 
 [![Latest Release](https://git.whoi.edu/ros/armw/-/badges/release.svg)](https://git.whoi.edu/ros/armw/-/releases) 

A shim layer that will let the same code run in ROS1 and ROS2
